summaryrefslogtreecommitdiff
path: root/deps/v8/tools/testrunner/base_runner.py
diff options
context:
space:
mode:
Diffstat (limited to 'deps/v8/tools/testrunner/base_runner.py')
-rw-r--r--deps/v8/tools/testrunner/base_runner.py40
1 files changed, 19 insertions, 21 deletions
diff --git a/deps/v8/tools/testrunner/base_runner.py b/deps/v8/tools/testrunner/base_runner.py
index cb23366aa4..d999d87a27 100644
--- a/deps/v8/tools/testrunner/base_runner.py
+++ b/deps/v8/tools/testrunner/base_runner.py
@@ -46,8 +46,10 @@ DEFAULT_OUT_GN = 'out.gn'
# Map of test name synonyms to lists of test suites. Should be ordered by
# expected runtimes (suites with slow test cases first). These groups are
# invoked in separate steps on the bots.
+# The mapping from names used here to GN targets (which must stay in sync)
+# is defined in infra/mb/gn_isolate_map.pyl.
TEST_MAP = {
- # This needs to stay in sync with test/bot_default.isolate.
+ # This needs to stay in sync with group("v8_bot_default") in test/BUILD.gn.
"bot_default": [
"debugger",
"mjsunit",
@@ -62,8 +64,9 @@ TEST_MAP = {
"preparser",
"intl",
"unittests",
+ "wasm-api-tests",
],
- # This needs to stay in sync with test/default.isolate.
+ # This needs to stay in sync with group("v8_default") in test/BUILD.gn.
"default": [
"debugger",
"mjsunit",
@@ -77,8 +80,9 @@ TEST_MAP = {
"preparser",
"intl",
"unittests",
+ "wasm-api-tests",
],
- # This needs to stay in sync with test/d8_default.isolate.
+ # This needs to stay in sync with group("v8_d8_default") in test/BUILD.gn.
"d8_default": [
"debugger",
"mjsunit",
@@ -87,7 +91,7 @@ TEST_MAP = {
"preparser",
"intl",
],
- # This needs to stay in sync with test/optimize_for_size.isolate.
+ # This needs to stay in sync with "v8_optimize_for_size" in test/BUILD.gn.
"optimize_for_size": [
"debugger",
"mjsunit",
@@ -190,7 +194,9 @@ class BuildConfig(object):
self.is_full_debug = build_config['is_full_debug']
self.msan = build_config['is_msan']
self.no_i18n = not build_config['v8_enable_i18n_support']
- self.no_snap = not build_config['v8_use_snapshot']
+ # TODO(https://crbug.com/v8/8531)
+ # 'v8_use_snapshot' was removed, 'no_snap' can be removed as well.
+ self.no_snap = False
self.predictable = build_config['v8_enable_verify_predictable']
self.tsan = build_config['is_tsan']
# TODO(machenbach): We only have ubsan not ubsan_vptr.
@@ -315,13 +321,11 @@ class BaseTestRunner(object):
default=False, action="store_true")
parser.add_option("--outdir", help="Base directory with compile output",
default="out")
- parser.add_option("--buildbot", help="DEPRECATED!",
- default=False, action="store_true")
parser.add_option("--arch",
help="The architecture to run tests for")
parser.add_option("-m", "--mode",
- help="The test mode in which to run (uppercase for ninja"
- " and buildbot builds): %s" % MODES.keys())
+ help="The test mode in which to run (uppercase for builds"
+ " in CI): %s" % MODES.keys())
parser.add_option("--shell-dir", help="DEPRECATED! Executables from build "
"directory will be used")
parser.add_option("--test-root", help="Root directory of the test suites",
@@ -350,9 +354,6 @@ class BaseTestRunner(object):
"color, mono)")
parser.add_option("--json-test-results",
help="Path to a file for storing json results.")
- parser.add_option("--junitout", help="File name of the JUnit output")
- parser.add_option("--junittestsuite", default="v8tests",
- help="The testsuite name in the JUnit output file")
parser.add_option("--exit-after-n-failures", type="int", default=100,
help="Exit after the first N failures instead of "
"running all tests. Pass 0 to disable this feature.")
@@ -436,7 +437,7 @@ class BaseTestRunner(object):
# gn
# outdir
# outdir/arch.mode
- # Each path is provided in two versions: <path> and <path>/mode for buildbot.
+ # Each path is provided in two versions: <path> and <path>/mode for bots.
def _possible_outdirs(self, options):
def outdirs():
if options.gn:
@@ -451,7 +452,7 @@ class BaseTestRunner(object):
for outdir in outdirs():
yield os.path.join(self.basedir, outdir)
- # buildbot option
+ # bot option
if options.mode:
yield os.path.join(self.basedir, outdir, options.mode)
@@ -493,9 +494,9 @@ class BaseTestRunner(object):
def _process_default_options(self, options):
# We don't use the mode for more path-magic.
# Therefore transform the buildbot mode here to fix build_config value.
if options.mode:
- options.mode = self._buildbot_to_v8_mode(options.mode)
+ options.mode = self._bot_to_v8_mode(options.mode)
build_config_mode = 'debug' if self.build_config.is_debug else 'release'
if options.mode:
@@ -535,8 +536,8 @@ class BaseTestRunner(object):
options.command_prefix = shlex.split(options.command_prefix)
options.extra_flags = sum(map(shlex.split, options.extra_flags), [])
- def _buildbot_to_v8_mode(self, config):
- """Convert buildbot build configs to configs understood by the v8 runner.
+ def _bot_to_v8_mode(self, config):
+ """Convert build configs from bots to configs understood by the v8 runner.
V8 configs are always lower case and without the additional _x64 suffix
for 64 bit builds on windows with ninja.
@@ -799,9 +800,6 @@ class BaseTestRunner(object):
def _create_progress_indicators(self, test_count, options):
procs = [PROGRESS_INDICATORS[options.progress]()]
- if options.junitout:
- procs.append(progress.JUnitTestProgressIndicator(options.junitout,
- options.junittestsuite))
if options.json_test_results:
procs.append(progress.JsonTestProgressIndicator(
self.framework_name,
@@ -493,9 +494,9 @@ class BaseTestRunner(object):
def _process_default_options(self, options):
# We don't use the mode for more path-magic.
- # Therefore transform the buildbot mode here to fix build_config value.
+ # Therefore transform the bot mode here to fix build_config value.
if options.mode: